==> haskell-bug-1.0.1-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bug.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bug
version:              1.0.1
visibility:           public
id:                   bug-1.0.1-4lF0FqIzswlB8ZYJbXhrK5
key:                  bug-1.0.1-4lF0FqIzswlB8ZYJbXhrK5
license:              MIT
copyright:            (c) 2017, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/bug
synopsis:             Better alternatives to the "error" function
category:             Development, Error Handling
abi:                  c92bb28a535766465d8109d2a3bd2036
exposed:              True
exposed-modules:      Bug
hidden-modules:       Bug.Formatting
import-dirs:          /usr/lib/ghc-8.10.1/site-local/bug-1.0.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/bug-1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/bug-1.0.1
hs-libraries:         HSbug-1.0.1-4lF0FqIzswlB8ZYJbXhrK5
depends:              base-4.14.0.0 template-haskell-2.16.0.0
haddock-interfaces:   /usr/share/doc/haskell-bug/html/bug.haddock
haddock-html:         /usr/share/doc/haskell-bug/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bug-1.0.1-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bug.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bug
version:              1.0.1
visibility:           public
id:                   bug-1.0.1-JLShIXmMB8CDt1eeAI0JXe
key:                  bug-1.0.1-JLShIXmMB8CDt1eeAI0JXe
license:              MIT
copyright:            (c) 2017, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/bug
synopsis:             Better alternatives to the "error" function
category:             Development, Error Handling
abi:                  7d27403786b2a1dff08cc0ff9262ddfc
exposed:              True
exposed-modules:      Bug
hidden-modules:       Bug.Formatting
import-dirs:          /usr/lib/ghc-8.10.2/site-local/bug-1.0.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/bug-1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/bug-1.0.1
hs-libraries:         HSbug-1.0.1-JLShIXmMB8CDt1eeAI0JXe
depends:              base-4.14.1.0 template-haskell-2.16.0.0
haddock-interfaces:   /usr/share/doc/haskell-bug/html/bug.haddock
haddock-html:         /usr/share/doc/haskell-bug/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
